
class Endpoints:
    BASE = "https://valorant-api.com/v1/"
    Agents = BASE + "agents"
    Buddies = BASE + "buddies"
    BuddyLevels = Buddies + "/levels"
    Bundles = BASE + "bundles"
    Ceremonies = BASE + "ceremonies"
    ContentTiers = BASE + "contenttiers"
    Currencies = BASE + "currencies"
    GameMode = BASE + "gamemodes"
    GamemodeEquippables = GameMode + "/equippables"
    Maps = BASE + "maps"
    PlayerCards = BASE + "playercards"
    PlayerTitles = BASE + "playertitles"
    Seasons = BASE + "seasons"
    Sprays = BASE + "sprays"
    SprayLevels = Sprays + "/levels"
    Themes = BASE + "themes"
    Weapons = BASE + "weapons"
    Version = BASE + "version"
    CompetitiveTiers = BASE + "competitivetiers"
    Competitive = Seasons + "/competitive"
    WeaponSkins = Weapons + "/skins"
    WeaponSkinChromas = Weapons + "/skinchromas"
    WeaponSkinLevels = Weapons + "/skinlevels"
    Contracts = BASE + "contracts"
    Events = BASE + "events"
    Gears = BASE + "gear"
    LevelBorders = BASE + "levelborders"
